@@ -278,6 +278,34 @@ class CfwClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeGuideScanInfo(self, request):
+        """DescribeGuideScanInfo新手引导扫描接口信息
+
+        :param request: Request instance for DescribeGuideScanInfo.
+        :type request: :class:`tencentcloud.cfw.v20190904.models.DescribeGuideScanInfoRequest`
+        :rtype: :class:`tencentcloud.cfw.v20190904.models.DescribeGuideScanInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeGuideScanInfo", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeGuideScanInfoResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeNatRuleOverview(self, request):
         """nat规则列表概况
 
